# max_ard

A Python SDK and CLI for working with ARD Imagery

## Introduction

`max_ard` consists of a Python SDK for selecting, ordering, and working with Maxar ARD imagery and a set of CLI tools  for common tasks.

## Installation

`pip install max-ard --extra-index-url https://packages.ard.maxar.com/`

## Prerequisites

If you are using the SDK or CLI to access data in an S3 bucket, you will need to configure your AWS credentials locally. If you install the AWS CLI tools and and can `aws s3 ls <bucket>` then you're set to go.

To interact with the ARD services, you also need to have ARD account credentials. Currently we store the credentials locally in a file in your home directory called `.ard-config`. It should contain:

```shell
[ard]
user_name = <your user name>
user_password = <your password>
```

The CLI tools can be used to create this file:

`max-ard login --username <your username> --password <your password`

## Documentation

The full user documentation is here:

https://ard.maxar.com/docs/sdk/

The source for these docs live in the `ard-docs` repo.

Autogenerated docs are in `/docs`, generated by `pdoc3`. See `scripts/update_docs.sh` for how to update the docs.

You can run `pdoc --http : max_ard` to run a preview server on `localhost:8080`.

Note that `pdoc3` is not in the Poetry dependencies because it is not compatible with Python 3.6. You will need to `pip install` it separately. 

## Development

This project uses Poetry for managing development. To get started using Poetry, ensure it is installed as per: https://python-poetry.org/docs/#installation.

To get started with development, create a local virtual env and install all the dependencies:

```shell
poetry config virtualenvs.in-project true --local
poetry install --extras full
```

If during development a new dependency is required, it can be added with the following:

```shell
poetry add <pkg_name> [--dev]
```

This project uses Numpy style docstrings. See https://numpydoc.readthedocs.io/en/latest/format.html for reference.

### Contributing

The following are steps that are to be followed during development:

- All work will be through feature branches, from master, referencing the Github issue number and a short name - ie: 55-improve-error-msgs
- All added code must covered by adequate tests that will be discovered by the current pytest configuration.
- All code must be formatted using Black, for example: `black max_ard/session.py`. Or if you are using VSCode, <ctrl><shift><I> will run the configured formatter (which should be Black as per `.vscode/settings.json`).
- All code must be formatted using isort as well, for example: `isort max_ard/session.py`.

> Note: Both black and isort are in pyproject.toml, and will be installed by Poetry with the above commands.

### Run Tests

There are some required env vars for running the tests, they can be found in the [.env-sample](.env-sample) file. It is up to the user to have those env vars active before running the tests. This file can be copied to a `.env` file (ARD creds need to be added), to be used with tools that support the format.

To run the tests prior to creating a PR:

```shell
poetry run ./scripts/tests
```

Many of the documentation pages are Jupyter Notebooks. To test the SDK against them, put a copy of the notebook in the `notebooks` directory. Cells tagged with "skip" are not executed.

## Releases

The script for making a new release is [scripts/release](scripts/release). This can be called directly as follows:

```shell
./scripts/release patch|minor|major|prepatch|preminor|premajor|prerelease
```

The semver argument will be passed to Poetry, see the Poetry docs for the different arguments: https://python-poetry.org/docs/cli/#version

For pre-releases, having a current version of 0.0.1, a pre-release version can be bumped by using `./scripts/release prepatch` or `./scripts/release prerelease`, which will result in `0.0.2-alpha.0`. Then to bump to `0.0.2`, run `poetry version patch`.

However, if you want to do a pre-release for a major or minor version, use the `premajor` or `preminor` argument. Then you can use `major` or `minor` to bump to the final version. Check the Poetry docs for more details.

> Note: You can run a local test install using the script [scripts/test_install](scripts/test_install). This script is used in `scripts/release`prior to trigering the full release.
